check_neighbors_object — Version 0.11.0.dev0

# check_neighbors_object

imblearn.utils.check_neighbors_object(nn_name, nn_object, additional_neighbor=0)

  Check the objects is consistent to be a k nearest neighbors.

  Several methods in `imblearn` relies on k nearest neighbors. These objects can be passed at initialisation as an integer or as an object that has KNeighborsMixin-like attributes. This utility will create or clone said object, ensuring it is KNeighbors-like.

  Parameters
    nn_namestr

      The name associated to the object to raise an error if needed.

    nn_objectint or KNeighborsMixin

      The object to be checked.

    additional_neighborint, default=0

      Sometimes, some algorithm need an additional neighbors.

  Returns
    nn_objectKNeighborsMixin

      The k-NN object.

previous

parametrize_with_checks

next

check_sampling_strategy